@@ -6,7 +6,7 @@ DRIVER_CONTROLLER_ID = 0
 OPERATOR_CONTROLLER_ID = 1
 
 
-class Joysticks:
+class _Joysticks:
     joysticks: list[wpilib.Joystick] = [
         wpilib.Joystick(DRIVER_CONTROLLER_ID),
         wpilib.Joystick(OPERATOR_CONTROLLER_ID)
@@ -15,9 +15,18 @@ class Joysticks:
 
 @dataclass
 class JoystickAxis:
+    """
+    Wrapper for wpilib joystick button
+    """
     controller_id: int
     axis_id: int
 
     @property
     def value(self) -> float:
-        return Joysticks.joysticks[self.controller_id].getRawAxis(self.axis_id)
+        """
+        Gets the value of the axis selected
+
+        Returns:
+            float: The value between -1 and 1 as a float
+        """
+        return _Joysticks.joysticks[self.controller_id].getRawAxis(self.axis_id)
